@@ -269,7 +269,9 @@ class OpenSesameIDE(BaseExtension):
             'open_file_extension_{}'.format(ext)
         )
         if not handler:
-            self._open_document_as_text(path)
+            from datamatrix import functional as fnc
+            with fnc.profile('profile-open.txt'):
+                self._open_document_as_text(path)
             return
         oslogger.debug('custom handler for .{} extension'.format(ext))
         handler_fnc, handler_desc = handler
@@ -308,10 +310,6 @@ class OpenSesameIDE(BaseExtension):
             clean_trailing_whitespaces=cfg.opensesame_ide_strip_lines,
             show_whitespaces=None
         )
-        self.extension_manager.fire(
-            u'register_editor',
-            editor=editor
-        )
 
     def remove_folder_browser_dock_widget(self, dock_widget):
 
@@ -625,6 +623,17 @@ class OpenSesameIDE(BaseExtension):
         """If the jupyter kernel is done, execute the next queued cell."""
         if self._cells_to_run_queue:
             QTimer.singleShot(1000, self._run_cell_from_queue)
+            
+    def event_jupyter_exception_occurred(self):
+        
+        self.extension_manager.fire(
+            u'notify',
+            message=_(u'An Exception occurred'),
+            category='warning',
+            always_show=True,
+            timeout=1000
+        )
+        self._cells_to_run_queue = []
         
     def _run_cell_from_queue(self):
         """Checks if there are cells cued to be executed. If so, then the cell
@@ -868,6 +877,7 @@ class OpenSesameIDE(BaseExtension):
         def inner(e):
 
             self.main_window.setUpdatesEnabled(False)
+            self._remember_pinned_files()
             self.extension_manager.fire('pyqode_suspend_auto_backend_restart')
             self._scetw.closeEvent(e)
             self.extension_manager.fire('pyqode_resume_auto_backend_restart')
@@ -957,7 +967,7 @@ class OpenSesameIDE(BaseExtension):
         tw.tab_closed.connect(self._on_editor_close)
         tw.split_requested.disconnect(splitter.split)
         tw.split_requested.connect(self._on_split_requested)
-        splitter.editor_created.connect(self._on_editor_created)
+        splitter.document_opened.connect(self._on_editor_created)
         
     def _on_split_requested(self, widget, orientation, index=None):
         
@@ -967,7 +977,7 @@ class OpenSesameIDE(BaseExtension):
     def _on_tabwidget_close(self, index):
 
         if self.tabwidget.get_widget(u'OpenSesameIDE') is None:
-            self._add_ide_tab()
+            QTimer.singleShot(1000, self._add_ide_tab)
         if self.tabwidget.count() > 1:
             return
         if not self.main_window.ui.action_onetabmode.isChecked():
@@ -1035,9 +1045,33 @@ class OpenSesameIDE(BaseExtension):
             if os.path.isdir(folder)
         ]
         if not folders:
+            oslogger.debug('opening current working directory')
             folders = [os.getcwd()]
         for folder in folders:
             self._open_folder(folder)
+            
+    def _remember_pinned_files(self):
+
+        paths = []
+        for editor in self._scetw.widgets(include_clones=True):
+            tab_widget = editor.parent().parent()
+            if editor.file.path is not None and editor.file.path not in paths:
+                if tab_widget.is_pinned(tab_widget.indexOf(editor)):
+                    paths.append(editor.file.path)
+        cfg.opensesame_ide_pinned_files = u';'.join(paths)
+            
+    def provide_ide_restored_pins(self):
+        
+        paths = [
+            path
+            for path in cfg.opensesame_ide_pinned_files.split(u';')
+            if os.path.isfile(path)
+        ]
+        for path in paths:
+            self.open_document(path)
+        for editor in self._scetw.widgets():
+            self._scetw.main_tab_widget.pin(editor)
+        return paths
     
     @BaseExtension.as_thread(wait=750)
     def _open_from_command_line(self, path):
