@@ -18,12 +18,13 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from libopensesame.py3compat import *
-from qdatamatrix import QDataMatrix
+from libqtopensesame.misc.config import cfg
 from datamatrix import DataMatrix
-from qtpy.QtWidgets import QDockWidget
+from qdatamatrix import QDataMatrix
+from qtpy.QtWidgets import QDockWidget, QLabel
+from qtpy.QtGui import QFont
 from qtpy.QtCore import Qt, QTimer
 from libopensesame.oslogging import oslogger
-from libqtopensesame.misc.config import cfg
 from libqtopensesame.extensions import BaseExtension
 from libqtopensesame.misc.translate import translation_context
 _ = translation_context(u'WorkspaceExplorer', category=u'extension')
@@ -45,7 +46,14 @@ class WorkspaceExplorer(BaseExtension):
         dm = DataMatrix(length=0)
         dm.initializing = -1
         self._workspace_cache = {}
+        self._label_kernel_not_supported = QLabel(
+            '<b>' + _('Kernel not supported') + '</b>'
+        )
+        self._label_kernel_not_supported.setAlignment(
+            Qt.AlignHCenter | Qt.AlignVCenter
+        )
         self._qdm = WorkspaceMatrix(dm, read_only=True)
+        self._qdm.setFont(QFont(cfg.pyqode_font_name, cfg.pyqode_font_size))
         self._qdm.cell_double_clicked.connect(self._inspect_variable)
         self._dock_widget = QDockWidget(self.main_window)
         self._dock_widget.setWidget(self._qdm)
@@ -71,10 +79,9 @@ class WorkspaceExplorer(BaseExtension):
             return
         if not row:
             return
-        name = self._qdm.dm.name[row - 1]
         self.extension_manager.fire(
             'data_viewer_inspect',
-            name=name,
+            name=self._qdm.dm.name[row - 1],
             workspace=self.extension_manager.provide('jupyter_workspace_name')
         )
 
@@ -107,6 +114,7 @@ class WorkspaceExplorer(BaseExtension):
             not self._dock_widget.isVisible()
         ):
             return
+        self._dock_widget.setWidget(self._qdm)
         self._dock_widget.setWindowTitle(_(u'Workspace ({})').format(name))
         workspace = workspace_func()
         self._workspace_cache[name] = workspace
@@ -121,6 +129,7 @@ class WorkspaceExplorer(BaseExtension):
         if workspace.get(u'not supported', False) is None:
             dm = DataMatrix(length=0)
             dm.kernel_not_supported = -1
+            self._dock_widget.setWidget(self._label_kernel_not_supported)
         # Create a DataMatrix that exposes the workspace
         else:
             dm = DataMatrix(length=len(workspace))
